@@ -49,7 +49,7 @@ impl From<GATING_A> for bool {
     }
 }
 #[doc = "Field `GATING` reader - Gating for PCLK"]
-pub struct GATING_R(crate::FieldReader<bool, GATING_A>);
+pub struct GATING_R(crate::FieldReader<bool>);
 impl GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl GATING_R {
     }
 }
 impl core::ops::Deref for GATING_R {
-    type Target = crate::FieldReader<bool, GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,12 +114,12 @@ impl<'a> GATING_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
 #[doc = "Field `DIV` reader - Factor M"]
-pub struct DIV_R(crate::FieldReader<u8, u8>);
+pub struct DIV_R(crate::FieldReader<u8>);
 impl DIV_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -127,7 +127,7 @@ impl DIV_R {
     }
 }
 impl core::ops::Deref for DIV_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -149,7 +149,7 @@ impl R {
     #[doc = "Bit 31 - Gating for PCLK"]
     #[inline(always)]
     pub fn gating(&self) -> GATING_R {
-        GATING_R::new(((self.bits >> 31) & 0x01) != 0)
+        GATING_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bits 0:4 - Factor M"]
     #[inline(always)]
