@@ -49,7 +49,7 @@ impl From<PLL_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_EN` reader - PLL Enable"]
-pub struct PLL_EN_R(crate::FieldReader<bool, PLL_EN_A>);
+pub struct PLL_EN_R(crate::FieldReader<bool>);
 impl PLL_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl PLL_EN_R {
     }
 }
 impl core::ops::Deref for PLL_EN_R {
-    type Target = crate::FieldReader<bool, PLL_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> PLL_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -133,7 +133,7 @@ impl From<PLL_LDO_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_LDO_EN` reader - LDO Enable"]
-pub struct PLL_LDO_EN_R(crate::FieldReader<bool, PLL_LDO_EN_A>);
+pub struct PLL_LDO_EN_R(crate::FieldReader<bool>);
 impl PLL_LDO_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -159,7 +159,7 @@ impl PLL_LDO_EN_R {
     }
 }
 impl core::ops::Deref for PLL_LDO_EN_R {
-    type Target = crate::FieldReader<bool, PLL_LDO_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -198,7 +198,7 @@ impl<'a> PLL_LDO_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -217,7 +217,7 @@ impl From<LOCK_ENABLE_A> for bool {
     }
 }
 #[doc = "Field `LOCK_ENABLE` reader - Lock Enable"]
-pub struct LOCK_ENABLE_R(crate::FieldReader<bool, LOCK_ENABLE_A>);
+pub struct LOCK_ENABLE_R(crate::FieldReader<bool>);
 impl LOCK_ENABLE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -243,7 +243,7 @@ impl LOCK_ENABLE_R {
     }
 }
 impl core::ops::Deref for LOCK_ENABLE_R {
-    type Target = crate::FieldReader<bool, LOCK_ENABLE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -282,7 +282,7 @@ impl<'a> LOCK_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -301,7 +301,7 @@ impl From<LOCK_A> for bool {
     }
 }
 #[doc = "Field `LOCK` reader - PLL Lock Status"]
-pub struct LOCK_R(crate::FieldReader<bool, LOCK_A>);
+pub struct LOCK_R(crate::FieldReader<bool>);
 impl LOCK_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -327,7 +327,7 @@ impl LOCK_R {
     }
 }
 impl core::ops::Deref for LOCK_R {
-    type Target = crate::FieldReader<bool, LOCK_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -348,7 +348,7 @@ impl From<PLL_OUTPUT_GATE_A> for bool {
     }
 }
 #[doc = "Field `PLL_OUTPUT_GATE` reader - PLL Output Gating Enable"]
-pub struct PLL_OUTPUT_GATE_R(crate::FieldReader<bool, PLL_OUTPUT_GATE_A>);
+pub struct PLL_OUTPUT_GATE_R(crate::FieldReader<bool>);
 impl PLL_OUTPUT_GATE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -374,7 +374,7 @@ impl PLL_OUTPUT_GATE_R {
     }
 }
 impl core::ops::Deref for PLL_OUTPUT_GATE_R {
-    type Target = crate::FieldReader<bool, PLL_OUTPUT_GATE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -413,12 +413,12 @@ impl<'a> PLL_OUTPUT_GATE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `PLL_LOCK_TIME` reader - PLL Lock Time"]
-pub struct PLL_LOCK_TIME_R(crate::FieldReader<u8, u8>);
+pub struct PLL_LOCK_TIME_R(crate::FieldReader<u8>);
 impl PLL_LOCK_TIME_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -426,7 +426,7 @@ impl PLL_LOCK_TIME_R {
     }
 }
 impl core::ops::Deref for PLL_LOCK_TIME_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -440,12 +440,12 @@ impl<'a> PLL_LOCK_TIME_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 24)) | ((value as u32 & 0x07) << 24);
+        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
         self.w
     }
 }
 #[doc = "Field `PLL_N` reader - PLL N"]
-pub struct PLL_N_R(crate::FieldReader<u8, u8>);
+pub struct PLL_N_R(crate::FieldReader<u8>);
 impl PLL_N_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -453,7 +453,7 @@ impl PLL_N_R {
     }
 }
 impl core::ops::Deref for PLL_N_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -489,7 +489,7 @@ impl From<PLL_UNLOCK_MDSEL_A> for u8 {
     }
 }
 #[doc = "Field `PLL_UNLOCK_MDSEL` reader - PLL Unlock Level"]
-pub struct PLL_UNLOCK_MDSEL_R(crate::FieldReader<u8, PLL_UNLOCK_MDSEL_A>);
+pub struct PLL_UNLOCK_MDSEL_R(crate::FieldReader<u8>);
 impl PLL_UNLOCK_MDSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -522,7 +522,7 @@ impl PLL_UNLOCK_MDSEL_R {
     }
 }
 impl core::ops::Deref for PLL_UNLOCK_MDSEL_R {
-    type Target = crate::FieldReader<u8, PLL_UNLOCK_MDSEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -556,7 +556,7 @@ impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -575,7 +575,7 @@ impl From<PLL_LOCK_MDSEL_A> for bool {
     }
 }
 #[doc = "Field `PLL_LOCK_MDSEL` reader - PLL Lock Level"]
-pub struct PLL_LOCK_MDSEL_R(crate::FieldReader<bool, PLL_LOCK_MDSEL_A>);
+pub struct PLL_LOCK_MDSEL_R(crate::FieldReader<bool>);
 impl PLL_LOCK_MDSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -601,7 +601,7 @@ impl PLL_LOCK_MDSEL_R {
     }
 }
 impl core::ops::Deref for PLL_LOCK_MDSEL_R {
-    type Target = crate::FieldReader<bool, PLL_LOCK_MDSEL_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -640,12 +640,12 @@ impl<'a> PLL_LOCK_MDSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `PLL_M` reader - PLL M"]
-pub struct PLL_M_R(crate::FieldReader<u8, u8>);
+pub struct PLL_M_R(crate::FieldReader<u8>);
 impl PLL_M_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -653,7 +653,7 @@ impl PLL_M_R {
     }
 }
 impl core::ops::Deref for PLL_M_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -667,7 +667,7 @@ impl<'a> PLL_M_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -675,32 +675,32 @@ impl R {
     #[doc = "Bit 31 - PLL Enable"]
     #[inline(always)]
     pub fn pll_en(&self) -> PLL_EN_R {
-        PLL_EN_R::new(((self.bits >> 31) & 0x01) != 0)
+        PLL_EN_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30 - LDO Enable"]
     #[inline(always)]
     pub fn pll_ldo_en(&self) -> PLL_LDO_EN_R {
-        PLL_LDO_EN_R::new(((self.bits >> 30) & 0x01) != 0)
+        PLL_LDO_EN_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 29 - Lock Enable"]
     #[inline(always)]
     pub fn lock_enable(&self) -> LOCK_ENABLE_R {
-        LOCK_ENABLE_R::new(((self.bits >> 29) & 0x01) != 0)
+        LOCK_ENABLE_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 28 - PLL Lock Status"]
     #[inline(always)]
     pub fn lock(&self) -> LOCK_R {
-        LOCK_R::new(((self.bits >> 28) & 0x01) != 0)
+        LOCK_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 27 - PLL Output Gating Enable"]
     #[inline(always)]
     pub fn pll_output_gate(&self) -> PLL_OUTPUT_GATE_R {
-        PLL_OUTPUT_GATE_R::new(((self.bits >> 27) & 0x01) != 0)
+        PLL_OUTPUT_GATE_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bits 24:26 - PLL Lock Time"]
     #[inline(always)]
     pub fn pll_lock_time(&self) -> PLL_LOCK_TIME_R {
-        PLL_LOCK_TIME_R::new(((self.bits >> 24) & 0x07) as u8)
+        PLL_LOCK_TIME_R::new(((self.bits >> 24) & 7) as u8)
     }
     #[doc = "Bits 8:15 - PLL N"]
     #[inline(always)]
@@ -710,17 +710,17 @@ impl R {
     #[doc = "Bits 6:7 - PLL Unlock Level"]
     #[inline(always)]
     pub fn pll_unlock_mdsel(&self) -> PLL_UNLOCK_MDSEL_R {
-        PLL_UNLOCK_MDSEL_R::new(((self.bits >> 6) & 0x03) as u8)
+        PLL_UNLOCK_MDSEL_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bit 5 - PLL Lock Level"]
     #[inline(always)]
     pub fn pll_lock_mdsel(&self) -> PLL_LOCK_MDSEL_R {
-        PLL_LOCK_MDSEL_R::new(((self.bits >> 5) & 0x01) != 0)
+        PLL_LOCK_MDSEL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bits 0:1 - PLL M"]
     #[inline(always)]
     pub fn pll_m(&self) -> PLL_M_R {
-        PLL_M_R::new((self.bits & 0x03) as u8)
+        PLL_M_R::new((self.bits & 3) as u8)
     }
 }
 impl W {
