@@ -49,7 +49,7 @@ impl From<PLL_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_EN` reader - PLL Enable"]
-pub struct PLL_EN_R(crate::FieldReader<bool, PLL_EN_A>);
+pub struct PLL_EN_R(crate::FieldReader<bool>);
 impl PLL_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl PLL_EN_R {
     }
 }
 impl core::ops::Deref for PLL_EN_R {
-    type Target = crate::FieldReader<bool, PLL_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> PLL_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -133,7 +133,7 @@ impl From<PLL_LDO_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_LDO_EN` reader - LDO Enable"]
-pub struct PLL_LDO_EN_R(crate::FieldReader<bool, PLL_LDO_EN_A>);
+pub struct PLL_LDO_EN_R(crate::FieldReader<bool>);
 impl PLL_LDO_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -159,7 +159,7 @@ impl PLL_LDO_EN_R {
     }
 }
 impl core::ops::Deref for PLL_LDO_EN_R {
-    type Target = crate::FieldReader<bool, PLL_LDO_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -198,7 +198,7 @@ impl<'a> PLL_LDO_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -217,7 +217,7 @@ impl From<LOCK_ENABLE_A> for bool {
     }
 }
 #[doc = "Field `LOCK_ENABLE` reader - Lock Enable"]
-pub struct LOCK_ENABLE_R(crate::FieldReader<bool, LOCK_ENABLE_A>);
+pub struct LOCK_ENABLE_R(crate::FieldReader<bool>);
 impl LOCK_ENABLE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -243,7 +243,7 @@ impl LOCK_ENABLE_R {
     }
 }
 impl core::ops::Deref for LOCK_ENABLE_R {
-    type Target = crate::FieldReader<bool, LOCK_ENABLE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -282,7 +282,7 @@ impl<'a> LOCK_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -301,7 +301,7 @@ impl From<LOCK_A> for bool {
     }
 }
 #[doc = "Field `LOCK` reader - PLL Lock Status"]
-pub struct LOCK_R(crate::FieldReader<bool, LOCK_A>);
+pub struct LOCK_R(crate::FieldReader<bool>);
 impl LOCK_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -327,7 +327,7 @@ impl LOCK_R {
     }
 }
 impl core::ops::Deref for LOCK_R {
-    type Target = crate::FieldReader<bool, LOCK_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -348,7 +348,7 @@ impl From<PLL_OUTPUT_GATE_A> for bool {
     }
 }
 #[doc = "Field `PLL_OUTPUT_GATE` reader - PLL Output Gating Enable"]
-pub struct PLL_OUTPUT_GATE_R(crate::FieldReader<bool, PLL_OUTPUT_GATE_A>);
+pub struct PLL_OUTPUT_GATE_R(crate::FieldReader<bool>);
 impl PLL_OUTPUT_GATE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -374,7 +374,7 @@ impl PLL_OUTPUT_GATE_R {
     }
 }
 impl core::ops::Deref for PLL_OUTPUT_GATE_R {
-    type Target = crate::FieldReader<bool, PLL_OUTPUT_GATE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -413,7 +413,7 @@ impl<'a> PLL_OUTPUT_GATE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -432,7 +432,7 @@ impl From<PLL_SDM_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_SDM_EN` reader - PLL SDM Enable"]
-pub struct PLL_SDM_EN_R(crate::FieldReader<bool, PLL_SDM_EN_A>);
+pub struct PLL_SDM_EN_R(crate::FieldReader<bool>);
 impl PLL_SDM_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -458,7 +458,7 @@ impl PLL_SDM_EN_R {
     }
 }
 impl core::ops::Deref for PLL_SDM_EN_R {
-    type Target = crate::FieldReader<bool, PLL_SDM_EN_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -497,12 +497,12 @@ impl<'a> PLL_SDM_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `PLL_N` reader - PLL N"]
-pub struct PLL_N_R(crate::FieldReader<u8, u8>);
+pub struct PLL_N_R(crate::FieldReader<u8>);
 impl PLL_N_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -510,7 +510,7 @@ impl PLL_N_R {
     }
 }
 impl core::ops::Deref for PLL_N_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -546,7 +546,7 @@ impl From<PLL_UNLOCK_MDSEL_A> for u8 {
     }
 }
 #[doc = "Field `PLL_UNLOCK_MDSEL` reader - PLL Unlock Level"]
-pub struct PLL_UNLOCK_MDSEL_R(crate::FieldReader<u8, PLL_UNLOCK_MDSEL_A>);
+pub struct PLL_UNLOCK_MDSEL_R(crate::FieldReader<u8>);
 impl PLL_UNLOCK_MDSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -579,7 +579,7 @@ impl PLL_UNLOCK_MDSEL_R {
     }
 }
 impl core::ops::Deref for PLL_UNLOCK_MDSEL_R {
-    type Target = crate::FieldReader<u8, PLL_UNLOCK_MDSEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -613,7 +613,7 @@ impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -632,7 +632,7 @@ impl From<PLL_LOCK_MDSEL_A> for bool {
     }
 }
 #[doc = "Field `PLL_LOCK_MDSEL` reader - PLL Lock Level"]
-pub struct PLL_LOCK_MDSEL_R(crate::FieldReader<bool, PLL_LOCK_MDSEL_A>);
+pub struct PLL_LOCK_MDSEL_R(crate::FieldReader<bool>);
 impl PLL_LOCK_MDSEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -658,7 +658,7 @@ impl PLL_LOCK_MDSEL_R {
     }
 }
 impl core::ops::Deref for PLL_LOCK_MDSEL_R {
-    type Target = crate::FieldReader<bool, PLL_LOCK_MDSEL_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -697,12 +697,12 @@ impl<'a> PLL_LOCK_MDSEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `PLL_INPUT_DIV2` reader - PLL Input Div M"]
-pub struct PLL_INPUT_DIV2_R(crate::FieldReader<bool, bool>);
+pub struct PLL_INPUT_DIV2_R(crate::FieldReader<bool>);
 impl PLL_INPUT_DIV2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -710,7 +710,7 @@ impl PLL_INPUT_DIV2_R {
     }
 }
 impl core::ops::Deref for PLL_INPUT_DIV2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -734,12 +734,12 @@ impl<'a> PLL_INPUT_DIV2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `PLL_OUTPUT_DIV2` reader - PLL Output Div D"]
-pub struct PLL_OUTPUT_DIV2_R(crate::FieldReader<bool, bool>);
+pub struct PLL_OUTPUT_DIV2_R(crate::FieldReader<bool>);
 impl PLL_OUTPUT_DIV2_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -747,7 +747,7 @@ impl PLL_OUTPUT_DIV2_R {
     }
 }
 impl core::ops::Deref for PLL_OUTPUT_DIV2_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -771,7 +771,7 @@ impl<'a> PLL_OUTPUT_DIV2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -779,32 +779,32 @@ impl R {
     #[doc = "Bit 31 - PLL Enable"]
     #[inline(always)]
     pub fn pll_en(&self) -> PLL_EN_R {
-        PLL_EN_R::new(((self.bits >> 31) & 0x01) != 0)
+        PLL_EN_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30 - LDO Enable"]
     #[inline(always)]
     pub fn pll_ldo_en(&self) -> PLL_LDO_EN_R {
-        PLL_LDO_EN_R::new(((self.bits >> 30) & 0x01) != 0)
+        PLL_LDO_EN_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 29 - Lock Enable"]
     #[inline(always)]
     pub fn lock_enable(&self) -> LOCK_ENABLE_R {
-        LOCK_ENABLE_R::new(((self.bits >> 29) & 0x01) != 0)
+        LOCK_ENABLE_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 28 - PLL Lock Status"]
     #[inline(always)]
     pub fn lock(&self) -> LOCK_R {
-        LOCK_R::new(((self.bits >> 28) & 0x01) != 0)
+        LOCK_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 27 - PLL Output Gating Enable"]
     #[inline(always)]
     pub fn pll_output_gate(&self) -> PLL_OUTPUT_GATE_R {
-        PLL_OUTPUT_GATE_R::new(((self.bits >> 27) & 0x01) != 0)
+        PLL_OUTPUT_GATE_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 24 - PLL SDM Enable"]
     #[inline(always)]
     pub fn pll_sdm_en(&self) -> PLL_SDM_EN_R {
-        PLL_SDM_EN_R::new(((self.bits >> 24) & 0x01) != 0)
+        PLL_SDM_EN_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bits 8:15 - PLL N"]
     #[inline(always)]
@@ -814,22 +814,22 @@ impl R {
     #[doc = "Bits 6:7 - PLL Unlock Level"]
     #[inline(always)]
     pub fn pll_unlock_mdsel(&self) -> PLL_UNLOCK_MDSEL_R {
-        PLL_UNLOCK_MDSEL_R::new(((self.bits >> 6) & 0x03) as u8)
+        PLL_UNLOCK_MDSEL_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bit 5 - PLL Lock Level"]
     #[inline(always)]
     pub fn pll_lock_mdsel(&self) -> PLL_LOCK_MDSEL_R {
-        PLL_LOCK_MDSEL_R::new(((self.bits >> 5) & 0x01) != 0)
+        PLL_LOCK_MDSEL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 1 - PLL Input Div M"]
     #[inline(always)]
     pub fn pll_input_div2(&self) -> PLL_INPUT_DIV2_R {
-        PLL_INPUT_DIV2_R::new(((self.bits >> 1) & 0x01) != 0)
+        PLL_INPUT_DIV2_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - PLL Output Div D"]
     #[inline(always)]
     pub fn pll_output_div2(&self) -> PLL_OUTPUT_DIV2_R {
-        PLL_OUTPUT_DIV2_R::new((self.bits & 0x01) != 0)
+        PLL_OUTPUT_DIV2_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
