@@ -54,7 +54,7 @@ impl From<CLK_SRC_SEL_A> for u8 {
     }
 }
 #[doc = "Field `CLK_SRC_SEL` reader - Clock Source Select"]
-pub struct CLK_SRC_SEL_R(crate::FieldReader<u8, CLK_SRC_SEL_A>);
+pub struct CLK_SRC_SEL_R(crate::FieldReader<u8>);
 impl CLK_SRC_SEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -93,7 +93,7 @@ impl CLK_SRC_SEL_R {
     }
 }
 impl core::ops::Deref for CLK_SRC_SEL_R {
-    type Target = crate::FieldReader<u8, CLK_SRC_SEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -132,7 +132,7 @@ impl<'a> CLK_SRC_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 24)) | ((value as u32 & 0x03) << 24);
+        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
         self.w
     }
 }
@@ -156,7 +156,7 @@ impl From<FACTOR_N_A> for u8 {
     }
 }
 #[doc = "Field `FACTOR_N` reader - Factor N"]
-pub struct FACTOR_N_R(crate::FieldReader<u8, FACTOR_N_A>);
+pub struct FACTOR_N_R(crate::FieldReader<u8>);
 impl FACTOR_N_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -195,7 +195,7 @@ impl FACTOR_N_R {
     }
 }
 impl core::ops::Deref for FACTOR_N_R {
-    type Target = crate::FieldReader<u8, FACTOR_N_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -234,12 +234,12 @@ impl<'a> FACTOR_N_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
 #[doc = "Field `FACTOR_M` reader - Factor M"]
-pub struct FACTOR_M_R(crate::FieldReader<u8, u8>);
+pub struct FACTOR_M_R(crate::FieldReader<u8>);
 impl FACTOR_M_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -247,7 +247,7 @@ impl FACTOR_M_R {
     }
 }
 impl core::ops::Deref for FACTOR_M_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -261,7 +261,7 @@ impl<'a> FACTOR_M_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -269,17 +269,17 @@ impl R {
     #[doc = "Bits 24:25 - Clock Source Select"]
     #[inline(always)]
     pub fn clk_src_sel(&self) -> CLK_SRC_SEL_R {
-        CLK_SRC_SEL_R::new(((self.bits >> 24) & 0x03) as u8)
+        CLK_SRC_SEL_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 8:9 - Factor N"]
     #[inline(always)]
     pub fn factor_n(&self) -> FACTOR_N_R {
-        FACTOR_N_R::new(((self.bits >> 8) & 0x03) as u8)
+        FACTOR_N_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 0:1 - Factor M"]
     #[inline(always)]
     pub fn factor_m(&self) -> FACTOR_M_R {
-        FACTOR_M_R::new((self.bits & 0x03) as u8)
+        FACTOR_M_R::new((self.bits & 3) as u8)
     }
 }
 impl W {
