@@ -49,7 +49,7 @@ impl From<USBOTG0_RST_A> for bool {
     }
 }
 #[doc = "Field `USBOTG0_RST` reader - USBOTG0 Reset"]
-pub struct USBOTG0_RST_R(crate::FieldReader<bool, USBOTG0_RST_A>);
+pub struct USBOTG0_RST_R(crate::FieldReader<bool>);
 impl USBOTG0_RST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl USBOTG0_RST_R {
     }
 }
 impl core::ops::Deref for USBOTG0_RST_R {
-    type Target = crate::FieldReader<bool, USBOTG0_RST_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,7 +114,7 @@ impl<'a> USBOTG0_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -133,7 +133,7 @@ impl From<USBEHCI_RST_A> for bool {
     }
 }
 #[doc = "Fields `USBEHCI(0-1)_RST` reader - USBEHCI Reset"]
-pub struct USBEHCI_RST_R(crate::FieldReader<bool, USBEHCI_RST_A>);
+pub struct USBEHCI_RST_R(crate::FieldReader<bool>);
 impl USBEHCI_RST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -159,56 +159,17 @@ impl USBEHCI_RST_R {
     }
 }
 impl core::ops::Deref for USBEHCI_RST_R {
-    type Target = crate::FieldReader<bool, USBEHCI_RST_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `USBEHCI(0-1)_RST` writer - USBEHCI Reset"]
-pub struct USBEHCI_RST_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> USBEHCI_RST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: USBEHCI_RST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn assert(self) -> &'a mut W {
-        self.variant(USBEHCI_RST_A::ASSERT)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn deassert(self) -> &'a mut W {
-        self.variant(USBEHCI_RST_A::DEASSERT)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `USBEHCI(0-1)_RST` const generic writer - USBEHCI Reset"]
-pub struct USBEHCI_RST_CGW<'a, const O: usize> {
+pub struct USBEHCI_RST_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> USBEHCI_RST_CGW<'a, O> {
+impl<'a, const O: usize> USBEHCI_RST_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBEHCI_RST_A) -> &'a mut W {
@@ -237,7 +198,7 @@ impl<'a, const O: usize> USBEHCI_RST_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -256,7 +217,7 @@ impl From<USBOHCI_RST_A> for bool {
     }
 }
 #[doc = "Fields `USBOHCI(0-1)_RST` reader - USBOHCI Reset"]
-pub struct USBOHCI_RST_R(crate::FieldReader<bool, USBOHCI_RST_A>);
+pub struct USBOHCI_RST_R(crate::FieldReader<bool>);
 impl USBOHCI_RST_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -282,56 +243,17 @@ impl USBOHCI_RST_R {
     }
 }
 impl core::ops::Deref for USBOHCI_RST_R {
-    type Target = crate::FieldReader<bool, USBOHCI_RST_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `USBOHCI(0-1)_RST` writer - USBOHCI Reset"]
-pub struct USBOHCI_RST_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> USBOHCI_RST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: USBOHCI_RST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn assert(self) -> &'a mut W {
-        self.variant(USBOHCI_RST_A::ASSERT)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn deassert(self) -> &'a mut W {
-        self.variant(USBOHCI_RST_A::DEASSERT)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `USBOHCI(0-1)_RST` const generic writer - USBOHCI Reset"]
-pub struct USBOHCI_RST_CGW<'a, const O: usize> {
+pub struct USBOHCI_RST_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> USBOHCI_RST_CGW<'a, O> {
+impl<'a, const O: usize> USBOHCI_RST_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBOHCI_RST_A) -> &'a mut W {
@@ -360,7 +282,7 @@ impl<'a, const O: usize> USBOHCI_RST_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -379,7 +301,7 @@ impl From<USBOTG0_GATING_A> for bool {
     }
 }
 #[doc = "Field `USBOTG0_GATING` reader - USBOTG0 Gating Clock"]
-pub struct USBOTG0_GATING_R(crate::FieldReader<bool, USBOTG0_GATING_A>);
+pub struct USBOTG0_GATING_R(crate::FieldReader<bool>);
 impl USBOTG0_GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -405,7 +327,7 @@ impl USBOTG0_GATING_R {
     }
 }
 impl core::ops::Deref for USBOTG0_GATING_R {
-    type Target = crate::FieldReader<bool, USBOTG0_GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -444,7 +366,7 @@ impl<'a> USBOTG0_GATING_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -463,7 +385,7 @@ impl From<USBEHCI_GATING_A> for bool {
     }
 }
 #[doc = "Fields `USBEHCI(0-1)_GATING` reader - USBEHCI Gating Clock"]
-pub struct USBEHCI_GATING_R(crate::FieldReader<bool, USBEHCI_GATING_A>);
+pub struct USBEHCI_GATING_R(crate::FieldReader<bool>);
 impl USBEHCI_GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -489,56 +411,17 @@ impl USBEHCI_GATING_R {
     }
 }
 impl core::ops::Deref for USBEHCI_GATING_R {
-    type Target = crate::FieldReader<bool, USBEHCI_GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `USBEHCI(0-1)_GATING` writer - USBEHCI Gating Clock"]
-pub struct USBEHCI_GATING_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> USBEHCI_GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: USBEHCI_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn mask(self) -> &'a mut W {
-        self.variant(USBEHCI_GATING_A::MASK)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn pass(self) -> &'a mut W {
-        self.variant(USBEHCI_GATING_A::PASS)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `USBEHCI(0-1)_GATING` const generic writer - USBEHCI Gating Clock"]
-pub struct USBEHCI_GATING_CGW<'a, const O: usize> {
+pub struct USBEHCI_GATING_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> USBEHCI_GATING_CGW<'a, O> {
+impl<'a, const O: usize> USBEHCI_GATING_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBEHCI_GATING_A) -> &'a mut W {
@@ -567,7 +450,7 @@ impl<'a, const O: usize> USBEHCI_GATING_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -586,7 +469,7 @@ impl From<USBOHCI_GATING_A> for bool {
     }
 }
 #[doc = "Fields `USBOHCI(0-1)_GATING` reader - USBOHCI Gating Clock"]
-pub struct USBOHCI_GATING_R(crate::FieldReader<bool, USBOHCI_GATING_A>);
+pub struct USBOHCI_GATING_R(crate::FieldReader<bool>);
 impl USBOHCI_GATING_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -612,56 +495,17 @@ impl USBOHCI_GATING_R {
     }
 }
 impl core::ops::Deref for USBOHCI_GATING_R {
-    type Target = crate::FieldReader<bool, USBOHCI_GATING_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `USBOHCI(0-1)_GATING` writer - USBOHCI Gating Clock"]
-pub struct USBOHCI_GATING_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> USBOHCI_GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: USBOHCI_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn mask(self) -> &'a mut W {
-        self.variant(USBOHCI_GATING_A::MASK)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn pass(self) -> &'a mut W {
-        self.variant(USBOHCI_GATING_A::PASS)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `USBOHCI(0-1)_GATING` const generic writer - USBOHCI Gating Clock"]
-pub struct USBOHCI_GATING_CGW<'a, const O: usize> {
+pub struct USBOHCI_GATING_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> USBOHCI_GATING_CGW<'a, O> {
+impl<'a, const O: usize> USBOHCI_GATING_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBOHCI_GATING_A) -> &'a mut W {
@@ -690,7 +534,7 @@ impl<'a, const O: usize> USBOHCI_GATING_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -698,72 +542,72 @@ impl R {
     #[doc = "Bit 24 - USBOTG0 Reset"]
     #[inline(always)]
     pub fn usbotg0_rst(&self) -> USBOTG0_RST_R {
-        USBOTG0_RST_R::new(((self.bits >> 24) & 0x01) != 0)
+        USBOTG0_RST_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "USBEHCI Reset"]
     #[inline(always)]
     pub unsafe fn usbehci_rst(&self, n: usize) -> USBEHCI_RST_R {
-        USBEHCI_RST_R::new(((self.bits >> (n + 20)) & 0x01) != 0)
+        USBEHCI_RST_R::new(((self.bits >> (n + 20)) & 1) != 0)
     }
     #[doc = "Bit 20 - USBEHCI Reset"]
     #[inline(always)]
     pub fn usbehci0_rst(&self) -> USBEHCI_RST_R {
-        USBEHCI_RST_R::new(((self.bits >> 20) & 0x01) != 0)
+        USBEHCI_RST_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - USBEHCI Reset"]
     #[inline(always)]
     pub fn usbehci1_rst(&self) -> USBEHCI_RST_R {
-        USBEHCI_RST_R::new(((self.bits >> 21) & 0x01) != 0)
+        USBEHCI_RST_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "USBOHCI Reset"]
     #[inline(always)]
     pub unsafe fn usbohci_rst(&self, n: usize) -> USBOHCI_RST_R {
-        USBOHCI_RST_R::new(((self.bits >> (n + 16)) & 0x01) != 0)
+        USBOHCI_RST_R::new(((self.bits >> (n + 16)) & 1) != 0)
     }
     #[doc = "Bit 16 - USBOHCI Reset"]
     #[inline(always)]
     pub fn usbohci0_rst(&self) -> USBOHCI_RST_R {
-        USBOHCI_RST_R::new(((self.bits >> 16) & 0x01) != 0)
+        USBOHCI_RST_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - USBOHCI Reset"]
     #[inline(always)]
     pub fn usbohci1_rst(&self) -> USBOHCI_RST_R {
-        USBOHCI_RST_R::new(((self.bits >> 17) & 0x01) != 0)
+        USBOHCI_RST_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 8 - USBOTG0 Gating Clock"]
     #[inline(always)]
     pub fn usbotg0_gating(&self) -> USBOTG0_GATING_R {
-        USBOTG0_GATING_R::new(((self.bits >> 8) & 0x01) != 0)
+        USBOTG0_GATING_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "USBEHCI Gating Clock"]
     #[inline(always)]
     pub unsafe fn usbehci_gating(&self, n: usize) -> USBEHCI_GATING_R {
-        USBEHCI_GATING_R::new(((self.bits >> (n + 4)) & 0x01) != 0)
+        USBEHCI_GATING_R::new(((self.bits >> (n + 4)) & 1) != 0)
     }
     #[doc = "Bit 4 - USBEHCI Gating Clock"]
     #[inline(always)]
     pub fn usbehci0_gating(&self) -> USBEHCI_GATING_R {
-        USBEHCI_GATING_R::new(((self.bits >> 4) & 0x01) != 0)
+        USBEHCI_GATING_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - USBEHCI Gating Clock"]
     #[inline(always)]
     pub fn usbehci1_gating(&self) -> USBEHCI_GATING_R {
-        USBEHCI_GATING_R::new(((self.bits >> 5) & 0x01) != 0)
+        USBEHCI_GATING_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "USBOHCI Gating Clock"]
     #[inline(always)]
     pub unsafe fn usbohci_gating(&self, n: usize) -> USBOHCI_GATING_R {
-        USBOHCI_GATING_R::new(((self.bits >> n) & 0x01) != 0)
+        USBOHCI_GATING_R::new(((self.bits >> n) & 1) != 0)
     }
     #[doc = "Bit 0 - USBOHCI Gating Clock"]
     #[inline(always)]
     pub fn usbohci0_gating(&self) -> USBOHCI_GATING_R {
-        USBOHCI_GATING_R::new((self.bits & 0x01) != 0)
+        USBOHCI_GATING_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - USBOHCI Gating Clock"]
     #[inline(always)]
     pub fn usbohci1_gating(&self) -> USBOHCI_GATING_R {
-        USBOHCI_GATING_R::new(((self.bits >> 1) & 0x01) != 0)
+        USBOHCI_GATING_R::new(((self.bits >> 1) & 1) != 0)
     }
 }
 impl W {
@@ -774,39 +618,33 @@ impl W {
     }
     #[doc = "USBEHCI Reset"]
     #[inline(always)]
-    pub unsafe fn usbehci_rst(&mut self, n: usize) -> USBEHCI_RST_W {
-        USBEHCI_RST_W {
-            w: self,
-            offset: n + 20,
-        }
+    pub unsafe fn usbehci_rst<const O: usize>(&mut self) -> USBEHCI_RST_W<O> {
+        USBEHCI_RST_W { w: self }
     }
     #[doc = "Bit 20 - USBEHCI Reset"]
     #[inline(always)]
-    pub fn usbehci0_rst(&mut self) -> USBEHCI_RST_CGW<20> {
-        USBEHCI_RST_CGW { w: self }
+    pub fn usbehci0_rst(&mut self) -> USBEHCI_RST_W<20> {
+        USBEHCI_RST_W { w: self }
     }
     #[doc = "Bit 21 - USBEHCI Reset"]
     #[inline(always)]
-    pub fn usbehci1_rst(&mut self) -> USBEHCI_RST_CGW<21> {
-        USBEHCI_RST_CGW { w: self }
+    pub fn usbehci1_rst(&mut self) -> USBEHCI_RST_W<21> {
+        USBEHCI_RST_W { w: self }
     }
     #[doc = "USBOHCI Reset"]
     #[inline(always)]
-    pub unsafe fn usbohci_rst(&mut self, n: usize) -> USBOHCI_RST_W {
-        USBOHCI_RST_W {
-            w: self,
-            offset: n + 16,
-        }
+    pub unsafe fn usbohci_rst<const O: usize>(&mut self) -> USBOHCI_RST_W<O> {
+        USBOHCI_RST_W { w: self }
     }
     #[doc = "Bit 16 - USBOHCI Reset"]
     #[inline(always)]
-    pub fn usbohci0_rst(&mut self) -> USBOHCI_RST_CGW<16> {
-        USBOHCI_RST_CGW { w: self }
+    pub fn usbohci0_rst(&mut self) -> USBOHCI_RST_W<16> {
+        USBOHCI_RST_W { w: self }
     }
     #[doc = "Bit 17 - USBOHCI Reset"]
     #[inline(always)]
-    pub fn usbohci1_rst(&mut self) -> USBOHCI_RST_CGW<17> {
-        USBOHCI_RST_CGW { w: self }
+    pub fn usbohci1_rst(&mut self) -> USBOHCI_RST_W<17> {
+        USBOHCI_RST_W { w: self }
     }
     #[doc = "Bit 8 - USBOTG0 Gating Clock"]
     #[inline(always)]
@@ -815,36 +653,33 @@ impl W {
     }
     #[doc = "USBEHCI Gating Clock"]
     #[inline(always)]
-    pub unsafe fn usbehci_gating(&mut self, n: usize) -> USBEHCI_GATING_W {
-        USBEHCI_GATING_W {
-            w: self,
-            offset: n + 4,
-        }
+    pub unsafe fn usbehci_gating<const O: usize>(&mut self) -> USBEHCI_GATING_W<O> {
+        USBEHCI_GATING_W { w: self }
     }
     #[doc = "Bit 4 - USBEHCI Gating Clock"]
     #[inline(always)]
-    pub fn usbehci0_gating(&mut self) -> USBEHCI_GATING_CGW<4> {
-        USBEHCI_GATING_CGW { w: self }
+    pub fn usbehci0_gating(&mut self) -> USBEHCI_GATING_W<4> {
+        USBEHCI_GATING_W { w: self }
     }
     #[doc = "Bit 5 - USBEHCI Gating Clock"]
     #[inline(always)]
-    pub fn usbehci1_gating(&mut self) -> USBEHCI_GATING_CGW<5> {
-        USBEHCI_GATING_CGW { w: self }
+    pub fn usbehci1_gating(&mut self) -> USBEHCI_GATING_W<5> {
+        USBEHCI_GATING_W { w: self }
     }
     #[doc = "USBOHCI Gating Clock"]
     #[inline(always)]
-    pub unsafe fn usbohci_gating(&mut self, n: usize) -> USBOHCI_GATING_W {
-        USBOHCI_GATING_W { w: self, offset: n }
+    pub unsafe fn usbohci_gating<const O: usize>(&mut self) -> USBOHCI_GATING_W<O> {
+        USBOHCI_GATING_W { w: self }
     }
     #[doc = "Bit 0 - USBOHCI Gating Clock"]
     #[inline(always)]
-    pub fn usbohci0_gating(&mut self) -> USBOHCI_GATING_CGW<0> {
-        USBOHCI_GATING_CGW { w: self }
+    pub fn usbohci0_gating(&mut self) -> USBOHCI_GATING_W<0> {
+        USBOHCI_GATING_W { w: self }
     }
     #[doc = "Bit 1 - USBOHCI Gating Clock"]
     #[inline(always)]
-    pub fn usbohci1_gating(&mut self) -> USBOHCI_GATING_CGW<1> {
-        USBOHCI_GATING_CGW { w: self }
+    pub fn usbohci1_gating(&mut self) -> USBOHCI_GATING_W<1> {
+        USBOHCI_GATING_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
