@@ -54,7 +54,7 @@ impl From<PB_DRV_A> for u8 {
     }
 }
 #[doc = "Fields `PB(8-12)_DRV` reader - PB Multi_Driving Select"]
-pub struct PB_DRV_R(crate::FieldReader<u8, PB_DRV_A>);
+pub struct PB_DRV_R(crate::FieldReader<u8>);
 impl PB_DRV_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -93,56 +93,17 @@ impl PB_DRV_R {
     }
 }
 impl core::ops::Deref for PB_DRV_R {
-    type Target = crate::FieldReader<u8, PB_DRV_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `PB(8-12)_DRV` writer - PB Multi_Driving Select"]
-pub struct PB_DRV_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> PB_DRV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PB_DRV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn l0(self) -> &'a mut W {
-        self.variant(PB_DRV_A::L0)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn l1(self) -> &'a mut W {
-        self.variant(PB_DRV_A::L1)
-    }
-    #[doc = "`10`"]
-    #[inline(always)]
-    pub fn l2(self) -> &'a mut W {
-        self.variant(PB_DRV_A::L2)
-    }
-    #[doc = "`11`"]
-    #[inline(always)]
-    pub fn l3(self) -> &'a mut W {
-        self.variant(PB_DRV_A::L3)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x03 << self.offset)) | ((value as u32 & 0x03) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `PB(8-12)_DRV` const generic writer - PB Multi_Driving Select"]
-pub struct PB_DRV_CGW<'a, const O: usize> {
+pub struct PB_DRV_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> PB_DRV_CGW<'a, O> {
+impl<'a, const O: usize> PB_DRV_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PB_DRV_A) -> &'a mut W {
@@ -171,7 +132,7 @@ impl<'a, const O: usize> PB_DRV_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << O)) | ((value as u32 & 0x03) << O);
+        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
         self.w
     }
 }
@@ -179,67 +140,64 @@ impl R {
     #[doc = "PB Multi_Driving Select"]
     #[inline(always)]
     pub unsafe fn pb_drv(&self, n: usize) -> PB_DRV_R {
-        PB_DRV_R::new(((self.bits >> ((n - 8) * 4)) & 0x03) as u8)
+        PB_DRV_R::new(((self.bits >> ((n - 8) * 4)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PB Multi_Driving Select"]
     #[inline(always)]
     pub fn pb8_drv(&self) -> PB_DRV_R {
-        PB_DRV_R::new((self.bits & 0x03) as u8)
+        PB_DRV_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 4:5 - PB Multi_Driving Select"]
     #[inline(always)]
     pub fn pb9_drv(&self) -> PB_DRV_R {
-        PB_DRV_R::new(((self.bits >> 4) & 0x03) as u8)
+        PB_DRV_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 8:9 - PB Multi_Driving Select"]
     #[inline(always)]
     pub fn pb10_drv(&self) -> PB_DRV_R {
-        PB_DRV_R::new(((self.bits >> 8) & 0x03) as u8)
+        PB_DRV_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 12:13 - PB Multi_Driving Select"]
     #[inline(always)]
     pub fn pb11_drv(&self) -> PB_DRV_R {
-        PB_DRV_R::new(((self.bits >> 12) & 0x03) as u8)
+        PB_DRV_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 16:17 - PB Multi_Driving Select"]
     #[inline(always)]
     pub fn pb12_drv(&self) -> PB_DRV_R {
-        PB_DRV_R::new(((self.bits >> 16) & 0x03) as u8)
+        PB_DRV_R::new(((self.bits >> 16) & 3) as u8)
     }
 }
 impl W {
     #[doc = "PB Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pb_drv(&mut self, n: usize) -> PB_DRV_W {
-        PB_DRV_W {
-            w: self,
-            offset: (n - 8) * 4,
-        }
+    pub unsafe fn pb_drv<const O: usize>(&mut self) -> PB_DRV_W<O> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Bits 0:1 - PB Multi_Driving Select"]
     #[inline(always)]
-    pub fn pb8_drv(&mut self) -> PB_DRV_CGW<0> {
-        PB_DRV_CGW { w: self }
+    pub fn pb8_drv(&mut self) -> PB_DRV_W<0> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Bits 4:5 - PB Multi_Driving Select"]
     #[inline(always)]
-    pub fn pb9_drv(&mut self) -> PB_DRV_CGW<4> {
-        PB_DRV_CGW { w: self }
+    pub fn pb9_drv(&mut self) -> PB_DRV_W<4> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Bits 8:9 - PB Multi_Driving Select"]
     #[inline(always)]
-    pub fn pb10_drv(&mut self) -> PB_DRV_CGW<8> {
-        PB_DRV_CGW { w: self }
+    pub fn pb10_drv(&mut self) -> PB_DRV_W<8> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Bits 12:13 - PB Multi_Driving Select"]
     #[inline(always)]
-    pub fn pb11_drv(&mut self) -> PB_DRV_CGW<12> {
-        PB_DRV_CGW { w: self }
+    pub fn pb11_drv(&mut self) -> PB_DRV_W<12> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Bits 16:17 - PB Multi_Driving Select"]
     #[inline(always)]
-    pub fn pb12_drv(&mut self) -> PB_DRV_CGW<16> {
-        PB_DRV_CGW { w: self }
+    pub fn pb12_drv(&mut self) -> PB_DRV_W<16> {
+        PB_DRV_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
