@@ -35,7 +35,7 @@ impl From<crate::W<PC_DAT_SPEC>> for W {
     }
 }
 #[doc = "Field `PC_DAT` reader - "]
-pub struct PC_DAT_R(crate::FieldReader<u8, u8>);
+pub struct PC_DAT_R(crate::FieldReader<u8>);
 impl PC_DAT_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -43,7 +43,7 @@ impl PC_DAT_R {
     }
 }
 impl core::ops::Deref for PC_DAT_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
