@@ -49,7 +49,7 @@ impl From<EINT_STATUS_A> for bool {
     }
 }
 #[doc = "Fields `EINT(0-7)_STATUS` reader - External INT Pending Bit"]
-pub struct EINT_STATUS_R(crate::FieldReader<bool, EINT_STATUS_A>);
+pub struct EINT_STATUS_R(crate::FieldReader<bool>);
 impl EINT_STATUS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,56 +75,17 @@ impl EINT_STATUS_R {
     }
 }
 impl core::ops::Deref for EINT_STATUS_R {
-    type Target = crate::FieldReader<bool, EINT_STATUS_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `EINT(0-7)_STATUS` writer - External INT Pending Bit"]
-pub struct EINT_STATUS_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> EINT_STATUS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: EINT_STATUS_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn no_pending(self) -> &'a mut W {
-        self.variant(EINT_STATUS_A::NO_PENDING)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn pending(self) -> &'a mut W {
-        self.variant(EINT_STATUS_A::PENDING)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x01 << self.offset)) | ((value as u32 & 0x01) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `EINT(0-7)_STATUS` const generic writer - External INT Pending Bit"]
-pub struct EINT_STATUS_CGW<'a, const O: usize> {
+pub struct EINT_STATUS_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> EINT_STATUS_CGW<'a, O> {
+impl<'a, const O: usize> EINT_STATUS_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EINT_STATUS_A) -> &'a mut W {
@@ -153,7 +114,7 @@ impl<'a, const O: usize> EINT_STATUS_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << O)) | ((value as u32 & 0x01) << O);
+        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
         self.w
     }
 }
@@ -161,94 +122,94 @@ impl R {
     #[doc = "External INT Pending Bit"]
     #[inline(always)]
     pub unsafe fn eint_status(&self, n: usize) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> n) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> n) & 1) != 0)
     }
     #[doc = "Bit 0 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint0_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new((self.bits & 0x01) != 0)
+        EINT_STATUS_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint1_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 1) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint2_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 2) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint3_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 3) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint4_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 4) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint5_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 5) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint6_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 6) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - External INT Pending Bit"]
     #[inline(always)]
     pub fn eint7_status(&self) -> EINT_STATUS_R {
-        EINT_STATUS_R::new(((self.bits >> 7) & 0x01) != 0)
+        EINT_STATUS_R::new(((self.bits >> 7) & 1) != 0)
     }
 }
 impl W {
     #[doc = "External INT Pending Bit"]
     #[inline(always)]
-    pub unsafe fn eint_status(&mut self, n: usize) -> EINT_STATUS_W {
-        EINT_STATUS_W { w: self, offset: n }
+    pub unsafe fn eint_status<const O: usize>(&mut self) -> EINT_STATUS_W<O> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 0 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint0_status(&mut self) -> EINT_STATUS_CGW<0> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint0_status(&mut self) -> EINT_STATUS_W<0> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 1 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint1_status(&mut self) -> EINT_STATUS_CGW<1> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint1_status(&mut self) -> EINT_STATUS_W<1> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 2 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint2_status(&mut self) -> EINT_STATUS_CGW<2> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint2_status(&mut self) -> EINT_STATUS_W<2> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 3 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint3_status(&mut self) -> EINT_STATUS_CGW<3> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint3_status(&mut self) -> EINT_STATUS_W<3> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 4 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint4_status(&mut self) -> EINT_STATUS_CGW<4> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint4_status(&mut self) -> EINT_STATUS_W<4> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 5 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint5_status(&mut self) -> EINT_STATUS_CGW<5> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint5_status(&mut self) -> EINT_STATUS_W<5> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 6 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint6_status(&mut self) -> EINT_STATUS_CGW<6> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint6_status(&mut self) -> EINT_STATUS_W<6> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Bit 7 - External INT Pending Bit"]
     #[inline(always)]
-    pub fn eint7_status(&mut self) -> EINT_STATUS_CGW<7> {
-        EINT_STATUS_CGW { w: self }
+    pub fn eint7_status(&mut self) -> EINT_STATUS_W<7> {
+        EINT_STATUS_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
