@@ -35,7 +35,7 @@ impl From<crate::W<PF_EINT_DEB_SPEC>> for W {
     }
 }
 #[doc = "Field `DEB_CLK_PRE_SCALE` reader - Debounce Clock Pre_scale n"]
-pub struct DEB_CLK_PRE_SCALE_R(crate::FieldReader<u8, u8>);
+pub struct DEB_CLK_PRE_SCALE_R(crate::FieldReader<u8>);
 impl DEB_CLK_PRE_SCALE_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -43,7 +43,7 @@ impl DEB_CLK_PRE_SCALE_R {
     }
 }
 impl core::ops::Deref for DEB_CLK_PRE_SCALE_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -57,7 +57,7 @@ impl<'a> DEB_CLK_PRE_SCALE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 4)) | ((value as u32 & 0x07) << 4);
+        self.w.bits = (self.w.bits & !(7 << 4)) | ((value as u32 & 7) << 4);
         self.w
     }
 }
@@ -76,7 +76,7 @@ impl From<PIO_INT_CLK_SELECT_A> for bool {
     }
 }
 #[doc = "Field `PIO_INT_CLK_SELECT` reader - PIO Interrupt Clock Select"]
-pub struct PIO_INT_CLK_SELECT_R(crate::FieldReader<bool, PIO_INT_CLK_SELECT_A>);
+pub struct PIO_INT_CLK_SELECT_R(crate::FieldReader<bool>);
 impl PIO_INT_CLK_SELECT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -102,7 +102,7 @@ impl PIO_INT_CLK_SELECT_R {
     }
 }
 impl core::ops::Deref for PIO_INT_CLK_SELECT_R {
-    type Target = crate::FieldReader<bool, PIO_INT_CLK_SELECT_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -141,7 +141,7 @@ impl<'a> PIO_INT_CLK_SELECT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -149,12 +149,12 @@ impl R {
     #[doc = "Bits 4:6 - Debounce Clock Pre_scale n"]
     #[inline(always)]
     pub fn deb_clk_pre_scale(&self) -> DEB_CLK_PRE_SCALE_R {
-        DEB_CLK_PRE_SCALE_R::new(((self.bits >> 4) & 0x07) as u8)
+        DEB_CLK_PRE_SCALE_R::new(((self.bits >> 4) & 7) as u8)
     }
     #[doc = "Bit 0 - PIO Interrupt Clock Select"]
     #[inline(always)]
     pub fn pio_int_clk_select(&self) -> PIO_INT_CLK_SELECT_R {
-        PIO_INT_CLK_SELECT_R::new((self.bits & 0x01) != 0)
+        PIO_INT_CLK_SELECT_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
