@@ -54,7 +54,7 @@ impl From<PG_DRV_A> for u8 {
     }
 }
 #[doc = "Fields `PG(0-7)_DRV` reader - PG Multi_Driving Select"]
-pub struct PG_DRV_R(crate::FieldReader<u8, PG_DRV_A>);
+pub struct PG_DRV_R(crate::FieldReader<u8>);
 impl PG_DRV_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -93,56 +93,17 @@ impl PG_DRV_R {
     }
 }
 impl core::ops::Deref for PG_DRV_R {
-    type Target = crate::FieldReader<u8, PG_DRV_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Fields `PG(0-7)_DRV` writer - PG Multi_Driving Select"]
-pub struct PG_DRV_W<'a> {
-    w: &'a mut W,
-    offset: usize,
-}
-impl<'a> PG_DRV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PG_DRV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
-    #[doc = "`0`"]
-    #[inline(always)]
-    pub fn l0(self) -> &'a mut W {
-        self.variant(PG_DRV_A::L0)
-    }
-    #[doc = "`1`"]
-    #[inline(always)]
-    pub fn l1(self) -> &'a mut W {
-        self.variant(PG_DRV_A::L1)
-    }
-    #[doc = "`10`"]
-    #[inline(always)]
-    pub fn l2(self) -> &'a mut W {
-        self.variant(PG_DRV_A::L2)
-    }
-    #[doc = "`11`"]
-    #[inline(always)]
-    pub fn l3(self) -> &'a mut W {
-        self.variant(PG_DRV_A::L3)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits =
-            (self.w.bits & !(0x03 << self.offset)) | ((value as u32 & 0x03) << self.offset);
-        self.w
-    }
-}
 #[doc = "Fields `PG(0-7)_DRV` const generic writer - PG Multi_Driving Select"]
-pub struct PG_DRV_CGW<'a, const O: usize> {
+pub struct PG_DRV_W<'a, const O: usize> {
     w: &'a mut W,
 }
-impl<'a, const O: usize> PG_DRV_CGW<'a, O> {
+impl<'a, const O: usize> PG_DRV_W<'a, O> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: PG_DRV_A) -> &'a mut W {
@@ -171,7 +132,7 @@ impl<'a, const O: usize> PG_DRV_CGW<'a, O> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << O)) | ((value as u32 & 0x03) << O);
+        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
         self.w
     }
 }
@@ -179,97 +140,94 @@ impl R {
     #[doc = "PG Multi_Driving Select"]
     #[inline(always)]
     pub unsafe fn pg_drv(&self, n: usize) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> (n * 4)) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> (n * 4)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg0_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new((self.bits & 0x03) as u8)
+        PG_DRV_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bits 4:5 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg1_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 4) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 8:9 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg2_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 8) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 12:13 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg3_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 12) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 16:17 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg4_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 16) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 20:21 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg5_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 20) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 20) & 3) as u8)
     }
     #[doc = "Bits 24:25 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg6_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 24) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 24) & 3) as u8)
     }
     #[doc = "Bits 28:29 - PG Multi_Driving Select"]
     #[inline(always)]
     pub fn pg7_drv(&self) -> PG_DRV_R {
-        PG_DRV_R::new(((self.bits >> 28) & 0x03) as u8)
+        PG_DRV_R::new(((self.bits >> 28) & 3) as u8)
     }
 }
 impl W {
     #[doc = "PG Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pg_drv(&mut self, n: usize) -> PG_DRV_W {
-        PG_DRV_W {
-            w: self,
-            offset: n * 4,
-        }
+    pub unsafe fn pg_drv<const O: usize>(&mut self) -> PG_DRV_W<O> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 0:1 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg0_drv(&mut self) -> PG_DRV_CGW<0> {
-        PG_DRV_CGW { w: self }
+    pub fn pg0_drv(&mut self) -> PG_DRV_W<0> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 4:5 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg1_drv(&mut self) -> PG_DRV_CGW<4> {
-        PG_DRV_CGW { w: self }
+    pub fn pg1_drv(&mut self) -> PG_DRV_W<4> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 8:9 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg2_drv(&mut self) -> PG_DRV_CGW<8> {
-        PG_DRV_CGW { w: self }
+    pub fn pg2_drv(&mut self) -> PG_DRV_W<8> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 12:13 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg3_drv(&mut self) -> PG_DRV_CGW<12> {
-        PG_DRV_CGW { w: self }
+    pub fn pg3_drv(&mut self) -> PG_DRV_W<12> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 16:17 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg4_drv(&mut self) -> PG_DRV_CGW<16> {
-        PG_DRV_CGW { w: self }
+    pub fn pg4_drv(&mut self) -> PG_DRV_W<16> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 20:21 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg5_drv(&mut self) -> PG_DRV_CGW<20> {
-        PG_DRV_CGW { w: self }
+    pub fn pg5_drv(&mut self) -> PG_DRV_W<20> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 24:25 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg6_drv(&mut self) -> PG_DRV_CGW<24> {
-        PG_DRV_CGW { w: self }
+    pub fn pg6_drv(&mut self) -> PG_DRV_W<24> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Bits 28:29 - PG Multi_Driving Select"]
     #[inline(always)]
-    pub fn pg7_drv(&mut self) -> PG_DRV_CGW<28> {
-        PG_DRV_CGW { w: self }
+    pub fn pg7_drv(&mut self) -> PG_DRV_W<28> {
+        PG_DRV_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
