@@ -35,7 +35,7 @@ impl From<crate::W<SPI_SAMP_DL_SPEC>> for W {
     }
 }
 #[doc = "Field `samp_dl_cal_start` reader - Sample Delay Calibration Start"]
-pub struct SAMP_DL_CAL_START_R(crate::FieldReader<bool, bool>);
+pub struct SAMP_DL_CAL_START_R(crate::FieldReader<bool>);
 impl SAMP_DL_CAL_START_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl SAMP_DL_CAL_START_R {
     }
 }
 impl core::ops::Deref for SAMP_DL_CAL_START_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,12 +67,12 @@ impl<'a> SAMP_DL_CAL_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `samp_dl_cal_done` reader - Sample Delay Calibration Dont"]
-pub struct SAMP_DL_CAL_DONE_R(crate::FieldReader<bool, bool>);
+pub struct SAMP_DL_CAL_DONE_R(crate::FieldReader<bool>);
 impl SAMP_DL_CAL_DONE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -80,14 +80,14 @@ impl SAMP_DL_CAL_DONE_R {
     }
 }
 impl core::ops::Deref for SAMP_DL_CAL_DONE_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `samp_dl` reader - Sample Delay"]
-pub struct SAMP_DL_R(crate::FieldReader<u8, u8>);
+pub struct SAMP_DL_R(crate::FieldReader<u8>);
 impl SAMP_DL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -95,14 +95,14 @@ impl SAMP_DL_R {
     }
 }
 impl core::ops::Deref for SAMP_DL_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
 #[doc = "Field `samp_dl_sw_en` reader - Sample Delay Software Enable"]
-pub struct SAMP_DL_SW_EN_R(crate::FieldReader<bool, bool>);
+pub struct SAMP_DL_SW_EN_R(crate::FieldReader<bool>);
 impl SAMP_DL_SW_EN_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -110,7 +110,7 @@ impl SAMP_DL_SW_EN_R {
     }
 }
 impl core::ops::Deref for SAMP_DL_SW_EN_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -134,12 +134,12 @@ impl<'a> SAMP_DL_SW_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `samp_dl_sw` reader - Sample Delay Software"]
-pub struct SAMP_DL_SW_R(crate::FieldReader<u8, u8>);
+pub struct SAMP_DL_SW_R(crate::FieldReader<u8>);
 impl SAMP_DL_SW_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -147,7 +147,7 @@ impl SAMP_DL_SW_R {
     }
 }
 impl core::ops::Deref for SAMP_DL_SW_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -169,12 +169,12 @@ impl R {
     #[doc = "Bit 15 - Sample Delay Calibration Start"]
     #[inline(always)]
     pub fn samp_dl_cal_start(&self) -> SAMP_DL_CAL_START_R {
-        SAMP_DL_CAL_START_R::new(((self.bits >> 15) & 0x01) != 0)
+        SAMP_DL_CAL_START_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 14 - Sample Delay Calibration Dont"]
     #[inline(always)]
     pub fn samp_dl_cal_done(&self) -> SAMP_DL_CAL_DONE_R {
-        SAMP_DL_CAL_DONE_R::new(((self.bits >> 14) & 0x01) != 0)
+        SAMP_DL_CAL_DONE_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bits 8:13 - Sample Delay"]
     #[inline(always)]
@@ -184,7 +184,7 @@ impl R {
     #[doc = "Bit 7 - Sample Delay Software Enable"]
     #[inline(always)]
     pub fn samp_dl_sw_en(&self) -> SAMP_DL_SW_EN_R {
-        SAMP_DL_SW_EN_R::new(((self.bits >> 7) & 0x01) != 0)
+        SAMP_DL_SW_EN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bits 0:5 - Sample Delay Software"]
     #[inline(always)]
