@@ -49,7 +49,7 @@ impl From<CMDT_A> for bool {
     }
 }
 #[doc = "Field `cmdt` reader - Command Type"]
-pub struct CMDT_R(crate::FieldReader<bool, CMDT_A>);
+pub struct CMDT_R(crate::FieldReader<bool>);
 impl CMDT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -75,7 +75,7 @@ impl CMDT_R {
     }
 }
 impl core::ops::Deref for CMDT_R {
-    type Target = crate::FieldReader<bool, CMDT_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -114,12 +114,12 @@ impl<'a> CMDT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
 #[doc = "Field `wcdc` reader - Write Command Dummy Cycles"]
-pub struct WCDC_R(crate::FieldReader<u16, u16>);
+pub struct WCDC_R(crate::FieldReader<u16>);
 impl WCDC_R {
     #[inline(always)]
     pub(crate) fn new(bits: u16) -> Self {
@@ -127,7 +127,7 @@ impl WCDC_R {
     }
 }
 impl core::ops::Deref for WCDC_R {
-    type Target = crate::FieldReader<u16, u16>;
+    type Target = crate::FieldReader<u16>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -160,7 +160,7 @@ impl From<DAT_SEQ_A> for bool {
     }
 }
 #[doc = "Field `dat_seq` reader - Output Data Sequence"]
-pub struct DAT_SEQ_R(crate::FieldReader<bool, DAT_SEQ_A>);
+pub struct DAT_SEQ_R(crate::FieldReader<bool>);
 impl DAT_SEQ_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -186,7 +186,7 @@ impl DAT_SEQ_R {
     }
 }
 impl core::ops::Deref for DAT_SEQ_R {
-    type Target = crate::FieldReader<bool, DAT_SEQ_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -225,7 +225,7 @@ impl<'a> DAT_SEQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -253,7 +253,7 @@ impl From<RGB_SEQ_A> for u8 {
     }
 }
 #[doc = "Field `rgb_seq` reader - Output RGB Sequence"]
-pub struct RGB_SEQ_R(crate::FieldReader<u8, RGB_SEQ_A>);
+pub struct RGB_SEQ_R(crate::FieldReader<u8>);
 impl RGB_SEQ_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -304,7 +304,7 @@ impl RGB_SEQ_R {
     }
 }
 impl core::ops::Deref for RGB_SEQ_R {
-    type Target = crate::FieldReader<u8, RGB_SEQ_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -353,7 +353,7 @@ impl<'a> RGB_SEQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 16)) | ((value as u32 & 0x07) << 16);
+        self.w.bits = (self.w.bits & !(7 << 16)) | ((value as u32 & 7) << 16);
         self.w
     }
 }
@@ -372,7 +372,7 @@ impl From<TRAN_MOD_A> for bool {
     }
 }
 #[doc = "Field `tran_mod` reader - Transmit Mode"]
-pub struct TRAN_MOD_R(crate::FieldReader<bool, TRAN_MOD_A>);
+pub struct TRAN_MOD_R(crate::FieldReader<bool>);
 impl TRAN_MOD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -398,7 +398,7 @@ impl TRAN_MOD_R {
     }
 }
 impl core::ops::Deref for TRAN_MOD_R {
-    type Target = crate::FieldReader<bool, TRAN_MOD_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -437,7 +437,7 @@ impl<'a> TRAN_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -463,7 +463,7 @@ impl From<DAT_FMT_A> for u8 {
     }
 }
 #[doc = "Field `dat_fmt` reader - Output Data Format"]
-pub struct DAT_FMT_R(crate::FieldReader<u8, DAT_FMT_A>);
+pub struct DAT_FMT_R(crate::FieldReader<u8>);
 impl DAT_FMT_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -508,7 +508,7 @@ impl DAT_FMT_R {
     }
 }
 impl core::ops::Deref for DAT_FMT_R {
-    type Target = crate::FieldReader<u8, DAT_FMT_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -552,7 +552,7 @@ impl<'a> DAT_FMT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 12)) | ((value as u32 & 0x07) << 12);
+        self.w.bits = (self.w.bits & !(7 << 12)) | ((value as u32 & 7) << 12);
         self.w
     }
 }
@@ -578,7 +578,7 @@ impl From<DBI_INTERFACE_A> for u8 {
     }
 }
 #[doc = "Field `dbi_interface` reader - "]
-pub struct DBI_INTERFACE_R(crate::FieldReader<u8, DBI_INTERFACE_A>);
+pub struct DBI_INTERFACE_R(crate::FieldReader<u8>);
 impl DBI_INTERFACE_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -623,7 +623,7 @@ impl DBI_INTERFACE_R {
     }
 }
 impl core::ops::Deref for DBI_INTERFACE_R {
-    type Target = crate::FieldReader<u8, DBI_INTERFACE_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -667,7 +667,7 @@ impl<'a> DBI_INTERFACE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 8)) | ((value as u32 & 0x07) << 8);
+        self.w.bits = (self.w.bits & !(7 << 8)) | ((value as u32 & 7) << 8);
         self.w
     }
 }
@@ -703,7 +703,7 @@ impl From<RGB_SRC_FMT_A> for u8 {
     }
 }
 #[doc = "Field `rgb_src_fmt` reader - RGB Source Format"]
-pub struct RGB_SRC_FMT_R(crate::FieldReader<u8, RGB_SRC_FMT_A>);
+pub struct RGB_SRC_FMT_R(crate::FieldReader<u8>);
 impl RGB_SRC_FMT_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -778,7 +778,7 @@ impl RGB_SRC_FMT_R {
     }
 }
 impl core::ops::Deref for RGB_SRC_FMT_R {
-    type Target = crate::FieldReader<u8, RGB_SRC_FMT_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -852,7 +852,7 @@ impl<'a> RGB_SRC_FMT_W<'a> {
     }
 }
 #[doc = "Field `dum_val` reader - Dummy Cycle Value"]
-pub struct DUM_VAL_R(crate::FieldReader<bool, bool>);
+pub struct DUM_VAL_R(crate::FieldReader<bool>);
 impl DUM_VAL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -860,7 +860,7 @@ impl DUM_VAL_R {
     }
 }
 impl core::ops::Deref for DUM_VAL_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -884,7 +884,7 @@ impl<'a> DUM_VAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -903,7 +903,7 @@ impl From<RGB_BO_A> for bool {
     }
 }
 #[doc = "Field `rgb_bo` reader - RGB Bit Order"]
-pub struct RGB_BO_R(crate::FieldReader<bool, RGB_BO_A>);
+pub struct RGB_BO_R(crate::FieldReader<bool>);
 impl RGB_BO_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -929,7 +929,7 @@ impl RGB_BO_R {
     }
 }
 impl core::ops::Deref for RGB_BO_R {
-    type Target = crate::FieldReader<bool, RGB_BO_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -968,7 +968,7 @@ impl<'a> RGB_BO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -987,7 +987,7 @@ impl From<ELEMENT_A_POS_A> for bool {
     }
 }
 #[doc = "Field `element_a_pos` reader - Element A Position"]
-pub struct ELEMENT_A_POS_R(crate::FieldReader<bool, ELEMENT_A_POS_A>);
+pub struct ELEMENT_A_POS_R(crate::FieldReader<bool>);
 impl ELEMENT_A_POS_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1013,7 +1013,7 @@ impl ELEMENT_A_POS_R {
     }
 }
 impl core::ops::Deref for ELEMENT_A_POS_R {
-    type Target = crate::FieldReader<bool, ELEMENT_A_POS_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1052,7 +1052,7 @@ impl<'a> ELEMENT_A_POS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -1071,7 +1071,7 @@ impl From<VI_SRC_TYPE_A> for bool {
     }
 }
 #[doc = "Field `vi_src_type` reader - Video Source Type"]
-pub struct VI_SRC_TYPE_R(crate::FieldReader<bool, VI_SRC_TYPE_A>);
+pub struct VI_SRC_TYPE_R(crate::FieldReader<bool>);
 impl VI_SRC_TYPE_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -1097,7 +1097,7 @@ impl VI_SRC_TYPE_R {
     }
 }
 impl core::ops::Deref for VI_SRC_TYPE_R {
-    type Target = crate::FieldReader<bool, VI_SRC_TYPE_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -1136,7 +1136,7 @@ impl<'a> VI_SRC_TYPE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -1144,7 +1144,7 @@ impl R {
     #[doc = "Bit 31 - Command Type"]
     #[inline(always)]
     pub fn cmdt(&self) -> CMDT_R {
-        CMDT_R::new(((self.bits >> 31) & 0x01) != 0)
+        CMDT_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bits 20:30 - Write Command Dummy Cycles"]
     #[inline(always)]
@@ -1154,27 +1154,27 @@ impl R {
     #[doc = "Bit 19 - Output Data Sequence"]
     #[inline(always)]
     pub fn dat_seq(&self) -> DAT_SEQ_R {
-        DAT_SEQ_R::new(((self.bits >> 19) & 0x01) != 0)
+        DAT_SEQ_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bits 16:18 - Output RGB Sequence"]
     #[inline(always)]
     pub fn rgb_seq(&self) -> RGB_SEQ_R {
-        RGB_SEQ_R::new(((self.bits >> 16) & 0x07) as u8)
+        RGB_SEQ_R::new(((self.bits >> 16) & 7) as u8)
     }
     #[doc = "Bit 15 - Transmit Mode"]
     #[inline(always)]
     pub fn tran_mod(&self) -> TRAN_MOD_R {
-        TRAN_MOD_R::new(((self.bits >> 15) & 0x01) != 0)
+        TRAN_MOD_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bits 12:14 - Output Data Format"]
     #[inline(always)]
     pub fn dat_fmt(&self) -> DAT_FMT_R {
-        DAT_FMT_R::new(((self.bits >> 12) & 0x07) as u8)
+        DAT_FMT_R::new(((self.bits >> 12) & 7) as u8)
     }
     #[doc = "Bits 8:10"]
     #[inline(always)]
     pub fn dbi_interface(&self) -> DBI_INTERFACE_R {
-        DBI_INTERFACE_R::new(((self.bits >> 8) & 0x07) as u8)
+        DBI_INTERFACE_R::new(((self.bits >> 8) & 7) as u8)
     }
     #[doc = "Bits 4:7 - RGB Source Format"]
     #[inline(always)]
@@ -1184,22 +1184,22 @@ impl R {
     #[doc = "Bit 3 - Dummy Cycle Value"]
     #[inline(always)]
     pub fn dum_val(&self) -> DUM_VAL_R {
-        DUM_VAL_R::new(((self.bits >> 3) & 0x01) != 0)
+        DUM_VAL_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2 - RGB Bit Order"]
     #[inline(always)]
     pub fn rgb_bo(&self) -> RGB_BO_R {
-        RGB_BO_R::new(((self.bits >> 2) & 0x01) != 0)
+        RGB_BO_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1 - Element A Position"]
     #[inline(always)]
     pub fn element_a_pos(&self) -> ELEMENT_A_POS_R {
-        ELEMENT_A_POS_R::new(((self.bits >> 1) & 0x01) != 0)
+        ELEMENT_A_POS_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - Video Source Type"]
     #[inline(always)]
     pub fn vi_src_type(&self) -> VI_SRC_TYPE_R {
-        VI_SRC_TYPE_R::new((self.bits & 0x01) != 0)
+        VI_SRC_TYPE_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
