@@ -35,7 +35,7 @@ impl From<crate::W<DBI_CTL_1_SPEC>> for W {
     }
 }
 #[doc = "Field `dbi_soft_trg` reader - DBI Soft Trigger"]
-pub struct DBI_SOFT_TRG_R(crate::FieldReader<bool, bool>);
+pub struct DBI_SOFT_TRG_R(crate::FieldReader<bool>);
 impl DBI_SOFT_TRG_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl DBI_SOFT_TRG_R {
     }
 }
 impl core::ops::Deref for DBI_SOFT_TRG_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,7 +67,7 @@ impl<'a> DBI_SOFT_TRG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -91,7 +91,7 @@ impl From<DBI_EN_MODE_SEL_A> for u8 {
     }
 }
 #[doc = "Field `dbi_en_mode_sel` reader - DBI Enable Mode Select"]
-pub struct DBI_EN_MODE_SEL_R(crate::FieldReader<u8, DBI_EN_MODE_SEL_A>);
+pub struct DBI_EN_MODE_SEL_R(crate::FieldReader<u8>);
 impl DBI_EN_MODE_SEL_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -130,7 +130,7 @@ impl DBI_EN_MODE_SEL_R {
     }
 }
 impl core::ops::Deref for DBI_EN_MODE_SEL_R {
-    type Target = crate::FieldReader<u8, DBI_EN_MODE_SEL_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -169,7 +169,7 @@ impl<'a> DBI_EN_MODE_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 29)) | ((value as u32 & 0x03) << 29);
+        self.w.bits = (self.w.bits & !(3 << 29)) | ((value as u32 & 3) << 29);
         self.w
     }
 }
@@ -191,7 +191,7 @@ impl From<RGB666_FMT_A> for u8 {
     }
 }
 #[doc = "Field `RGB666_FMT` reader - 2 Data Lane RGB666 Format"]
-pub struct RGB666_FMT_R(crate::FieldReader<u8, RGB666_FMT_A>);
+pub struct RGB666_FMT_R(crate::FieldReader<u8>);
 impl RGB666_FMT_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -224,7 +224,7 @@ impl RGB666_FMT_R {
     }
 }
 impl core::ops::Deref for RGB666_FMT_R {
-    type Target = crate::FieldReader<u8, RGB666_FMT_A>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -258,7 +258,7 @@ impl<'a> RGB666_FMT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 26)) | ((value as u32 & 0x03) << 26);
+        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
         self.w
     }
 }
@@ -277,7 +277,7 @@ impl From<DBI_RXCLK_INV_A> for bool {
     }
 }
 #[doc = "Field `dbi_rxclk_inv` reader - DBI RX Clock Inverse"]
-pub struct DBI_RXCLK_INV_R(crate::FieldReader<bool, DBI_RXCLK_INV_A>);
+pub struct DBI_RXCLK_INV_R(crate::FieldReader<bool>);
 impl DBI_RXCLK_INV_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -303,7 +303,7 @@ impl DBI_RXCLK_INV_R {
     }
 }
 impl core::ops::Deref for DBI_RXCLK_INV_R {
-    type Target = crate::FieldReader<bool, DBI_RXCLK_INV_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -342,7 +342,7 @@ impl<'a> DBI_RXCLK_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -361,7 +361,7 @@ impl From<DBI_CLKO_MOD_A> for bool {
     }
 }
 #[doc = "Field `dbi_clko_mod` reader - DBI Output Clock Mode"]
-pub struct DBI_CLKO_MOD_R(crate::FieldReader<bool, DBI_CLKO_MOD_A>);
+pub struct DBI_CLKO_MOD_R(crate::FieldReader<bool>);
 impl DBI_CLKO_MOD_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -387,7 +387,7 @@ impl DBI_CLKO_MOD_R {
     }
 }
 impl core::ops::Deref for DBI_CLKO_MOD_R {
-    type Target = crate::FieldReader<bool, DBI_CLKO_MOD_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -426,12 +426,12 @@ impl<'a> DBI_CLKO_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `dbi_clko_inv` reader - DBI Clock Output Inverse"]
-pub struct DBI_CLKO_INV_R(crate::FieldReader<bool, bool>);
+pub struct DBI_CLKO_INV_R(crate::FieldReader<bool>);
 impl DBI_CLKO_INV_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -439,7 +439,7 @@ impl DBI_CLKO_INV_R {
     }
 }
 impl core::ops::Deref for DBI_CLKO_INV_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -463,12 +463,12 @@ impl<'a> DBI_CLKO_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `dcx_data` reader - DCX Data Value"]
-pub struct DCX_DATA_R(crate::FieldReader<bool, bool>);
+pub struct DCX_DATA_R(crate::FieldReader<bool>);
 impl DCX_DATA_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -476,7 +476,7 @@ impl DCX_DATA_R {
     }
 }
 impl core::ops::Deref for DCX_DATA_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -500,12 +500,12 @@ impl<'a> DCX_DATA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `RGB16_data_source_select` reader - RGB 16 Data Source Select"]
-pub struct RGB16_DATA_SOURCE_SELECT_R(crate::FieldReader<bool, bool>);
+pub struct RGB16_DATA_SOURCE_SELECT_R(crate::FieldReader<bool>);
 impl RGB16_DATA_SOURCE_SELECT_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -513,7 +513,7 @@ impl RGB16_DATA_SOURCE_SELECT_R {
     }
 }
 impl core::ops::Deref for RGB16_DATA_SOURCE_SELECT_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -537,12 +537,12 @@ impl<'a> RGB16_DATA_SOURCE_SELECT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `rdat_lsb` reader - Bit Order of Read Data"]
-pub struct RDAT_LSB_R(crate::FieldReader<bool, bool>);
+pub struct RDAT_LSB_R(crate::FieldReader<bool>);
 impl RDAT_LSB_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -550,7 +550,7 @@ impl RDAT_LSB_R {
     }
 }
 impl core::ops::Deref for RDAT_LSB_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -574,12 +574,12 @@ impl<'a> RDAT_LSB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `rcdc` reader - Read Command Dummy Cycles"]
-pub struct RCDC_R(crate::FieldReader<u8, u8>);
+pub struct RCDC_R(crate::FieldReader<u8>);
 impl RCDC_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -587,7 +587,7 @@ impl RCDC_R {
     }
 }
 impl core::ops::Deref for RCDC_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -606,7 +606,7 @@ impl<'a> RCDC_W<'a> {
     }
 }
 #[doc = "Field `rdbn` reader - Read Data Number of Bytes"]
-pub struct RDBN_R(crate::FieldReader<u8, u8>);
+pub struct RDBN_R(crate::FieldReader<u8>);
 impl RDBN_R {
     #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
@@ -614,7 +614,7 @@ impl RDBN_R {
     }
 }
 impl core::ops::Deref for RDBN_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u8>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -636,47 +636,47 @@ impl R {
     #[doc = "Bit 31 - DBI Soft Trigger"]
     #[inline(always)]
     pub fn dbi_soft_trg(&self) -> DBI_SOFT_TRG_R {
-        DBI_SOFT_TRG_R::new(((self.bits >> 31) & 0x01) != 0)
+        DBI_SOFT_TRG_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bits 29:30 - DBI Enable Mode Select"]
     #[inline(always)]
     pub fn dbi_en_mode_sel(&self) -> DBI_EN_MODE_SEL_R {
-        DBI_EN_MODE_SEL_R::new(((self.bits >> 29) & 0x03) as u8)
+        DBI_EN_MODE_SEL_R::new(((self.bits >> 29) & 3) as u8)
     }
     #[doc = "Bits 26:27 - 2 Data Lane RGB666 Format"]
     #[inline(always)]
     pub fn rgb666_fmt(&self) -> RGB666_FMT_R {
-        RGB666_FMT_R::new(((self.bits >> 26) & 0x03) as u8)
+        RGB666_FMT_R::new(((self.bits >> 26) & 3) as u8)
     }
     #[doc = "Bit 25 - DBI RX Clock Inverse"]
     #[inline(always)]
     pub fn dbi_rxclk_inv(&self) -> DBI_RXCLK_INV_R {
-        DBI_RXCLK_INV_R::new(((self.bits >> 25) & 0x01) != 0)
+        DBI_RXCLK_INV_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 24 - DBI Output Clock Mode"]
     #[inline(always)]
     pub fn dbi_clko_mod(&self) -> DBI_CLKO_MOD_R {
-        DBI_CLKO_MOD_R::new(((self.bits >> 24) & 0x01) != 0)
+        DBI_CLKO_MOD_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 23 - DBI Clock Output Inverse"]
     #[inline(always)]
     pub fn dbi_clko_inv(&self) -> DBI_CLKO_INV_R {
-        DBI_CLKO_INV_R::new(((self.bits >> 23) & 0x01) != 0)
+        DBI_CLKO_INV_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 22 - DCX Data Value"]
     #[inline(always)]
     pub fn dcx_data(&self) -> DCX_DATA_R {
-        DCX_DATA_R::new(((self.bits >> 22) & 0x01) != 0)
+        DCX_DATA_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 21 - RGB 16 Data Source Select"]
     #[inline(always)]
     pub fn rgb16_data_source_select(&self) -> RGB16_DATA_SOURCE_SELECT_R {
-        RGB16_DATA_SOURCE_SELECT_R::new(((self.bits >> 21) & 0x01) != 0)
+        RGB16_DATA_SOURCE_SELECT_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 20 - Bit Order of Read Data"]
     #[inline(always)]
     pub fn rdat_lsb(&self) -> RDAT_LSB_R {
-        RDAT_LSB_R::new(((self.bits >> 20) & 0x01) != 0)
+        RDAT_LSB_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bits 8:15 - Read Command Dummy Cycles"]
     #[inline(always)]
