@@ -35,7 +35,7 @@ impl From<crate::W<SPI_ISR_SPEC>> for W {
     }
 }
 #[doc = "Field `ssi` reader - SS Invalid Enable"]
-pub struct SSI_R(crate::FieldReader<bool, bool>);
+pub struct SSI_R(crate::FieldReader<bool>);
 impl SSI_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -43,7 +43,7 @@ impl SSI_R {
     }
 }
 impl core::ops::Deref for SSI_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -67,7 +67,7 @@ impl<'a> SSI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -86,7 +86,7 @@ impl From<TC_A> for bool {
     }
 }
 #[doc = "Field `tc` reader - Transfer Completed"]
-pub struct TC_R(crate::FieldReader<bool, TC_A>);
+pub struct TC_R(crate::FieldReader<bool>);
 impl TC_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -112,7 +112,7 @@ impl TC_R {
     }
 }
 impl core::ops::Deref for TC_R {
-    type Target = crate::FieldReader<bool, TC_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -151,7 +151,7 @@ impl<'a> TC_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -170,7 +170,7 @@ impl From<TF_UDR_A> for bool {
     }
 }
 #[doc = "Field `tf_udr` reader - TXFIFO Underrun"]
-pub struct TF_UDR_R(crate::FieldReader<bool, TF_UDR_A>);
+pub struct TF_UDR_R(crate::FieldReader<bool>);
 impl TF_UDR_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -196,7 +196,7 @@ impl TF_UDR_R {
     }
 }
 impl core::ops::Deref for TF_UDR_R {
-    type Target = crate::FieldReader<bool, TF_UDR_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -235,7 +235,7 @@ impl<'a> TF_UDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -254,7 +254,7 @@ impl From<TF_OVF_A> for bool {
     }
 }
 #[doc = "Field `tf_ovf` reader - TXFIFO Overflow"]
-pub struct TF_OVF_R(crate::FieldReader<bool, TF_OVF_A>);
+pub struct TF_OVF_R(crate::FieldReader<bool>);
 impl TF_OVF_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -280,7 +280,7 @@ impl TF_OVF_R {
     }
 }
 impl core::ops::Deref for TF_OVF_R {
-    type Target = crate::FieldReader<bool, TF_OVF_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -319,7 +319,7 @@ impl<'a> TF_OVF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -338,7 +338,7 @@ impl From<RF_UDR_A> for bool {
     }
 }
 #[doc = "Field `rf_udr` reader - RXFIFO Underrun"]
-pub struct RF_UDR_R(crate::FieldReader<bool, RF_UDR_A>);
+pub struct RF_UDR_R(crate::FieldReader<bool>);
 impl RF_UDR_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -364,7 +364,7 @@ impl RF_UDR_R {
     }
 }
 impl core::ops::Deref for RF_UDR_R {
-    type Target = crate::FieldReader<bool, RF_UDR_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -403,7 +403,7 @@ impl<'a> RF_UDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -422,7 +422,7 @@ impl From<RF_OVF_A> for bool {
     }
 }
 #[doc = "Field `rf_ovf` reader - RXFIFO Overflow"]
-pub struct RF_OVF_R(crate::FieldReader<bool, RF_OVF_A>);
+pub struct RF_OVF_R(crate::FieldReader<bool>);
 impl RF_OVF_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -448,7 +448,7 @@ impl RF_OVF_R {
     }
 }
 impl core::ops::Deref for RF_OVF_R {
-    type Target = crate::FieldReader<bool, RF_OVF_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -487,7 +487,7 @@ impl<'a> RF_OVF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -506,7 +506,7 @@ impl From<TF_FULL_A> for bool {
     }
 }
 #[doc = "Field `tf_full` reader - TXFIFO Full"]
-pub struct TF_FULL_R(crate::FieldReader<bool, TF_FULL_A>);
+pub struct TF_FULL_R(crate::FieldReader<bool>);
 impl TF_FULL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -532,7 +532,7 @@ impl TF_FULL_R {
     }
 }
 impl core::ops::Deref for TF_FULL_R {
-    type Target = crate::FieldReader<bool, TF_FULL_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -571,7 +571,7 @@ impl<'a> TF_FULL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -590,7 +590,7 @@ impl From<TF_EMP_A> for bool {
     }
 }
 #[doc = "Field `tf_emp` reader - TXFIFO Empty"]
-pub struct TF_EMP_R(crate::FieldReader<bool, TF_EMP_A>);
+pub struct TF_EMP_R(crate::FieldReader<bool>);
 impl TF_EMP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -616,7 +616,7 @@ impl TF_EMP_R {
     }
 }
 impl core::ops::Deref for TF_EMP_R {
-    type Target = crate::FieldReader<bool, TF_EMP_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -655,12 +655,12 @@ impl<'a> TF_EMP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `tf_ready` reader - TXFIFO Ready"]
-pub struct TF_READY_R(crate::FieldReader<bool, bool>);
+pub struct TF_READY_R(crate::FieldReader<bool>);
 impl TF_READY_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -668,7 +668,7 @@ impl TF_READY_R {
     }
 }
 impl core::ops::Deref for TF_READY_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -692,7 +692,7 @@ impl<'a> TF_READY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -711,7 +711,7 @@ impl From<RF_FULL_A> for bool {
     }
 }
 #[doc = "Field `rf_full` reader - RXFIFO Full"]
-pub struct RF_FULL_R(crate::FieldReader<bool, RF_FULL_A>);
+pub struct RF_FULL_R(crate::FieldReader<bool>);
 impl RF_FULL_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -737,7 +737,7 @@ impl RF_FULL_R {
     }
 }
 impl core::ops::Deref for RF_FULL_R {
-    type Target = crate::FieldReader<bool, RF_FULL_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -776,7 +776,7 @@ impl<'a> RF_FULL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -795,7 +795,7 @@ impl From<RF_EMP_A> for bool {
     }
 }
 #[doc = "Field `rf_emp` reader - RXFIFO Empty"]
-pub struct RF_EMP_R(crate::FieldReader<bool, RF_EMP_A>);
+pub struct RF_EMP_R(crate::FieldReader<bool>);
 impl RF_EMP_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -821,7 +821,7 @@ impl RF_EMP_R {
     }
 }
 impl core::ops::Deref for RF_EMP_R {
-    type Target = crate::FieldReader<bool, RF_EMP_A>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -860,12 +860,12 @@ impl<'a> RF_EMP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `rf_rdy` reader - RXFIFO Ready"]
-pub struct RF_RDY_R(crate::FieldReader<bool, bool>);
+pub struct RF_RDY_R(crate::FieldReader<bool>);
 impl RF_RDY_R {
     #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
@@ -873,7 +873,7 @@ impl RF_RDY_R {
     }
 }
 impl core::ops::Deref for RF_RDY_R {
-    type Target = crate::FieldReader<bool, bool>;
+    type Target = crate::FieldReader<bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -897,7 +897,7 @@ impl<'a> RF_RDY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -905,62 +905,62 @@ impl R {
     #[doc = "Bit 13 - SS Invalid Enable"]
     #[inline(always)]
     pub fn ssi(&self) -> SSI_R {
-        SSI_R::new(((self.bits >> 13) & 0x01) != 0)
+        SSI_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 12 - Transfer Completed"]
     #[inline(always)]
     pub fn tc(&self) -> TC_R {
-        TC_R::new(((self.bits >> 12) & 0x01) != 0)
+        TC_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 11 - TXFIFO Underrun"]
     #[inline(always)]
     pub fn tf_udr(&self) -> TF_UDR_R {
-        TF_UDR_R::new(((self.bits >> 11) & 0x01) != 0)
+        TF_UDR_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 10 - TXFIFO Overflow"]
     #[inline(always)]
     pub fn tf_ovf(&self) -> TF_OVF_R {
-        TF_OVF_R::new(((self.bits >> 10) & 0x01) != 0)
+        TF_OVF_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 9 - RXFIFO Underrun"]
     #[inline(always)]
     pub fn rf_udr(&self) -> RF_UDR_R {
-        RF_UDR_R::new(((self.bits >> 9) & 0x01) != 0)
+        RF_UDR_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 8 - RXFIFO Overflow"]
     #[inline(always)]
     pub fn rf_ovf(&self) -> RF_OVF_R {
-        RF_OVF_R::new(((self.bits >> 8) & 0x01) != 0)
+        RF_OVF_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 6 - TXFIFO Full"]
     #[inline(always)]
     pub fn tf_full(&self) -> TF_FULL_R {
-        TF_FULL_R::new(((self.bits >> 6) & 0x01) != 0)
+        TF_FULL_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5 - TXFIFO Empty"]
     #[inline(always)]
     pub fn tf_emp(&self) -> TF_EMP_R {
-        TF_EMP_R::new(((self.bits >> 5) & 0x01) != 0)
+        TF_EMP_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 4 - TXFIFO Ready"]
     #[inline(always)]
     pub fn tf_ready(&self) -> TF_READY_R {
-        TF_READY_R::new(((self.bits >> 4) & 0x01) != 0)
+        TF_READY_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 2 - RXFIFO Full"]
     #[inline(always)]
     pub fn rf_full(&self) -> RF_FULL_R {
-        RF_FULL_R::new(((self.bits >> 2) & 0x01) != 0)
+        RF_FULL_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1 - RXFIFO Empty"]
     #[inline(always)]
     pub fn rf_emp(&self) -> RF_EMP_R {
-        RF_EMP_R::new(((self.bits >> 1) & 0x01) != 0)
+        RF_EMP_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - RXFIFO Ready"]
     #[inline(always)]
     pub fn rf_rdy(&self) -> RF_RDY_R {
-        RF_RDY_R::new((self.bits & 0x01) != 0)
+        RF_RDY_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
